<?php
/*
Plugin Name: Hyperlink Word Across Site
Description: Hyperlinks a specific word across your WordPress site, ensuring it's only linked once per page and monitors future content. Adds option to change hyperlink color.
Version: 1.1.1
Author: Your Name
*/

function hyperlink_word_content($content) {
    $word_to_link = get_option('hyperlink_word');
    $link_url = get_option('hyperlink_url');
    $link_color = get_option('hyperlink_color');
    $new_tab = get_option('hyperlink_new_tab') ? 'target="_blank" rel="noopener noreferrer"' : '';

    if (empty($word_to_link) || empty($link_url)) {
        return $content;
    }

    $unique_id = 'hyperlink_done_' . md5($word_to_link . $link_url);

    if (strpos($content, $unique_id) === false) {
        $regex = '/\b' . preg_quote($word_to_link, '/') . '\b/i';
        $style = !empty($link_color) ? 'style="color: ' . esc_attr($link_color) . ';"' : '';
        $linked_word = '<a href="' . esc_url($link_url) . '" ' . $new_tab . ' ' . $style . '>' . esc_html($word_to_link) . '</a><span style="display:none;" id="' . $unique_id . '"></span>';

        $content = preg_replace($regex, $linked_word, $content, 1);
    }

    return $content;
}

add_filter('the_content', 'hyperlink_word_content');

function hyperlink_word_admin_menu() {
    add_menu_page(
        'Hyperlink Word Settings', // Page title
        'Hyperlink Word', // Menu title
        'manage_options', // Capability
        'hyperlink-word-settings', // Menu slug
        'hyperlink_word_settings_page', // Callback function
        'dashicons-admin-links', // Icon (optional)
        20 // Position (optional)
    );
}

add_action('admin_menu', 'hyperlink_word_admin_menu');

function hyperlink_word_settings_page() {
    if (isset($_POST['hyperlink_word']) && isset($_POST['hyperlink_url']) && isset($_POST['hyperlink_color']) && isset($_POST['hyperlink_new_tab'])) {
        update_option('hyperlink_word', sanitize_text_field($_POST['hyperlink_word']));
        update_option('hyperlink_url', esc_url_raw($_POST['hyperlink_url']));
        update_option('hyperlink_color', sanitize_hex_color($_POST['hyperlink_color'])); //Use sanitize_hex_color()
        update_option('hyperlink_new_tab', isset($_POST['hyperlink_new_tab']) ? 1 : 0);
        echo '<div class="updated"><p>Settings saved.</p></div>';
    }

    $word = get_option('hyperlink_word');
    $url = get_option('hyperlink_url');
    $color = get_option('hyperlink_color');
    $new_tab = get_option('hyperlink_new_tab');
    ?>
    <div class="wrap">
        <h2>Hyperlink Word Settings</h2>
        <form method="post">
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Word to Hyperlink:</th>
                    <td><input type="text" name="hyperlink_word" value="<?php echo esc_attr($word); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Link URL:</th>
                    <td><input type="text" name="hyperlink_url" value="<?php echo esc_url($url); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Hyperlink Color:</th>
                    <td><input type="color" name="hyperlink_color" value="<?php echo esc_attr($color); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Open in New Tab:</th>
                    <td><input type="checkbox" name="hyperlink_new_tab" value="1" <?php checked($new_tab, 1); ?> /></td>
                </tr>
            </table>
            <p class="submit">
                <input type="submit" class="button-primary" value="Save Changes" />
            </p>
        </form>
    </div>
    <?php
}
?>